/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIScriptSecurityManager.idl
 */

#ifndef __gen_nsIScriptSecurityManager_h__
#define __gen_nsIScriptSecurityManager_h__

#include "nsISupports.h"
#include "nsIPrincipal.h"

#include "jspubtd.h"
class nsIURI; /* forward declaration */


/* starting interface:    nsIScriptSecurityManager */
#define NS_ISCRIPTSECURITYMANAGER_IID_STR "58df5780-8006-11d2-bd91-00805f8ae3f4"

#define NS_ISCRIPTSECURITYMANAGER_IID \
  {0x58df5780, 0x8006, 0x11d2, \
    { 0xbd, 0x91, 0x00, 0x80, 0x5f, 0x8a, 0xe3, 0xf4 }}

class NS_NO_VTABLE nsIScriptSecurityManager : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISCRIPTSECURITYMANAGER_IID)

  /**
	 * Return the principal of the innermost frame of the currently 
	 * executing script. Will return null if there is no script 
	 * currently executing.
	 */
  /* nsIPrincipal GetSubjectPrincipal (); */
  NS_IMETHOD GetSubjectPrincipal(nsIPrincipal **_retval) = 0;

  /**
	 * Return the all-powerful system principal.
	 */
  /* nsIPrincipal GetSystemPrincipal (); */
  NS_IMETHOD GetSystemPrincipal(nsIPrincipal **_retval) = 0;

  /**
	 * Return a principal that can be QI'd to nsICodebasePrincipal and 
	 * has the same origin as aURI.
	 */
  /* nsIPrincipal GetCodebasePrincipal (in nsIURI aURI); */
  NS_IMETHOD GetCodebasePrincipal(nsIURI *aURI, nsIPrincipal **_retval) = 0;

  /**
	 * Return a principal that can be QI'd to nsICertificatePrincipal.
	 */
  /* nsIPrincipal GetCertificatePrincipal (in string CertID); */
  NS_IMETHOD GetCertificatePrincipal(const char *CertID, nsIPrincipal **_retval) = 0;

  /**
     * Checks whether the currently executing script can access the given 
     * property.
     *
     * @param cx The current active JavaScript context
     * @param obj The object that is being accessed
     * @param prop The ordinal of the property being accessed (see nsDOMPropEnums.h)
     * @param isWrite True if write access is being attempted
     */
  /* void CheckScriptAccess (in JSContextPtr cx, in voidPtr obj, in long prop, in boolean isWrite); */
  NS_IMETHOD CheckScriptAccess(JSContext * cx, void * obj, PRInt32 prop, PRBool isWrite) = 0;

  /**
	 * Check that the script with context "cx" can load "uri".
	 *
	 * Will return error code NS_ERROR_DOM_BAD_URI if the load request 
	 * should be denied.
	 *
	 * @param cx the JSContext of the script causing the load
	 * @param uri the URI that is being loaded
	 */
  /* void CheckLoadURIFromScript (in JSContextPtr cx, in nsIURI uri); */
  NS_IMETHOD CheckLoadURIFromScript(JSContext * cx, nsIURI *uri) = 0;

  /**
	 * Check that content from "from" can load "uri".
	 *
	 * Will return error code NS_ERROR_DOM_BAD_URI if the load request 
	 * should be denied.
	 *
	 * @param from the URI causing the load
	 * @param uri the URI that is being loaded
	 * @param disallowFromMail if true, return NS_ERROR_DOM_BAD_URI if 'from'
	 *                         is a URI associated with mail or news
	 */
  /* void CheckLoadURI (in nsIURI from, in nsIURI uri, in boolean disallowFromMail); */
  NS_IMETHOD CheckLoadURI(nsIURI *from, nsIURI *uri, PRBool disallowFromMail) = 0;

  /**
   * Check that the function 'funObj' is allowed to run on 'targetObj'
   *
   * Will return error code NS_ERROR_DOM_SECURITY_ERR if the function
   * should not run
   *
   * @param cx The current active JavaScript context.
   * @param funObj The function trying to run..
   * @param targetObj The object the function will run on.
   */
  /* void CheckFunctionAccess (in JSContextPtr cx, in voidPtr funObj, in voidPtr targetObj); */
  NS_IMETHOD CheckFunctionAccess(JSContext * cx, void * funObj, void * targetObj) = 0;

  /**
	 * Return true if content from the given principal is allowed to
	 * execute scripts.
	 */
  /* boolean CanExecuteScripts (in nsIPrincipal principal); */
  NS_IMETHOD CanExecuteScripts(nsIPrincipal *principal, PRBool *_retval) = 0;

  /**
     * Request that 'capability' can be enabled by scripts or applets running 
     * with 'principal'. Will prompt user if necessary. Returns 
     * nsIPrincipal::ENABLE_GRANTED or nsIPrincipal::ENABLE_DENIED based on user's choice.
     */
  /* void RequestCapability (in nsIPrincipal principal, in string capability, out short result); */
  NS_IMETHOD RequestCapability(nsIPrincipal *principal, const char *capability, PRInt16 *result) = 0;

  /**
	 * Return true if the currently executing script has 'capability' enabled.
	 */
  /* boolean IsCapabilityEnabled (in string capability); */
  NS_IMETHOD IsCapabilityEnabled(const char *capability, PRBool *_retval) = 0;

  /**
	 * Enable 'capability' in the innermost frame of the currently executing
	 * script.
	 */
  /* void EnableCapability (in string capability); */
  NS_IMETHOD EnableCapability(const char *capability) = 0;

  /**
	 * Remove 'capability' from the innermost frame of the currently executing
	 * script. Any setting of 'capability' from enclosing frames thus comes into
	 * effect.
	 */
  /* void RevertCapability (in string capability); */
  NS_IMETHOD RevertCapability(const char *capability) = 0;

  /**
	 * Disable 'capability' in the innermost frame of the currently executing
	 * script.
	 */
  /* void DisableCapability (in string capability); */
  NS_IMETHOD DisableCapability(const char *capability) = 0;

  /**
	 * Allow 'certificateID' to enable 'capability.' Can only be performed
     * by code signed by the system certificate.
	 */
  /* void SetCanEnableCapability (in string certificateID, in string capability, in short canEnable); */
  NS_IMETHOD SetCanEnableCapability(const char *certificateID, const char *capability, PRInt16 canEnable) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISCRIPTSECURITYMANAGER \
  NS_IMETHOD GetSubjectPrincipal(nsIPrincipal **_retval); \
  NS_IMETHOD GetSystemPrincipal(nsIPrincipal **_retval); \
  NS_IMETHOD GetCodebasePrincipal(nsIURI *aURI, nsIPrincipal **_retval); \
  NS_IMETHOD GetCertificatePrincipal(const char *CertID, nsIPrincipal **_retval); \
  NS_IMETHOD CheckScriptAccess(JSContext * cx, void * obj, PRInt32 prop, PRBool isWrite); \
  NS_IMETHOD CheckLoadURIFromScript(JSContext * cx, nsIURI *uri); \
  NS_IMETHOD CheckLoadURI(nsIURI *from, nsIURI *uri, PRBool disallowFromMail); \
  NS_IMETHOD CheckFunctionAccess(JSContext * cx, void * funObj, void * targetObj); \
  NS_IMETHOD CanExecuteScripts(nsIPrincipal *principal, PRBool *_retval); \
  NS_IMETHOD RequestCapability(nsIPrincipal *principal, const char *capability, PRInt16 *result); \
  NS_IMETHOD IsCapabilityEnabled(const char *capability, PRBool *_retval); \
  NS_IMETHOD EnableCapability(const char *capability); \
  NS_IMETHOD RevertCapability(const char *capability); \
  NS_IMETHOD DisableCapability(const char *capability); \
  NS_IMETHOD SetCanEnableCapability(const char *certificateID, const char *capability, PRInt16 canEnable); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISCRIPTSECURITYMANAGER(_to) \
  NS_IMETHOD GetSubjectPrincipal(nsIPrincipal **_retval) { return _to ## GetSubjectPrincipal(_retval); } \
  NS_IMETHOD GetSystemPrincipal(nsIPrincipal **_retval) { return _to ## GetSystemPrincipal(_retval); } \
  NS_IMETHOD GetCodebasePrincipal(nsIURI *aURI, nsIPrincipal **_retval) { return _to ## GetCodebasePrincipal(aURI, _retval); } \
  NS_IMETHOD GetCertificatePrincipal(const char *CertID, nsIPrincipal **_retval) { return _to ## GetCertificatePrincipal(CertID, _retval); } \
  NS_IMETHOD CheckScriptAccess(JSContext * cx, void * obj, PRInt32 prop, PRBool isWrite) { return _to ## CheckScriptAccess(cx, obj, prop, isWrite); } \
  NS_IMETHOD CheckLoadURIFromScript(JSContext * cx, nsIURI *uri) { return _to ## CheckLoadURIFromScript(cx, uri); } \
  NS_IMETHOD CheckLoadURI(nsIURI *from, nsIURI *uri, PRBool disallowFromMail) { return _to ## CheckLoadURI(from, uri, disallowFromMail); } \
  NS_IMETHOD CheckFunctionAccess(JSContext * cx, void * funObj, void * targetObj) { return _to ## CheckFunctionAccess(cx, funObj, targetObj); } \
  NS_IMETHOD CanExecuteScripts(nsIPrincipal *principal, PRBool *_retval) { return _to ## CanExecuteScripts(principal, _retval); } \
  NS_IMETHOD RequestCapability(nsIPrincipal *principal, const char *capability, PRInt16 *result) { return _to ## RequestCapability(principal, capability, result); } \
  NS_IMETHOD IsCapabilityEnabled(const char *capability, PRBool *_retval) { return _to ## IsCapabilityEnabled(capability, _retval); } \
  NS_IMETHOD EnableCapability(const char *capability) { return _to ## EnableCapability(capability); } \
  NS_IMETHOD RevertCapability(const char *capability) { return _to ## RevertCapability(capability); } \
  NS_IMETHOD DisableCapability(const char *capability) { return _to ## DisableCapability(capability); } \
  NS_IMETHOD SetCanEnableCapability(const char *certificateID, const char *capability, PRInt16 canEnable) { return _to ## SetCanEnableCapability(certificateID, capability, canEnable); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsScriptSecurityManager : public nsIScriptSecurityManager
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISCRIPTSECURITYMANAGER

  nsScriptSecurityManager();
  virtual ~nsScriptSecurityManager();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsScriptSecurityManager, nsIScriptSecurityManager)

nsScriptSecurityManager::nsScriptSecurityManager()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsScriptSecurityManager::~nsScriptSecurityManager()
{
  /* destructor code */
}

/* nsIPrincipal GetSubjectPrincipal (); */
NS_IMETHODIMP nsScriptSecurityManager::GetSubjectPrincipal(nsIPrincipal **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIPrincipal GetSystemPrincipal (); */
NS_IMETHODIMP nsScriptSecurityManager::GetSystemPrincipal(nsIPrincipal **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIPrincipal GetCodebasePrincipal (in nsIURI aURI); */
NS_IMETHODIMP nsScriptSecurityManager::GetCodebasePrincipal(nsIURI *aURI, nsIPrincipal **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIPrincipal GetCertificatePrincipal (in string CertID); */
NS_IMETHODIMP nsScriptSecurityManager::GetCertificatePrincipal(const char *CertID, nsIPrincipal **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CheckScriptAccess (in JSContextPtr cx, in voidPtr obj, in long prop, in boolean isWrite); */
NS_IMETHODIMP nsScriptSecurityManager::CheckScriptAccess(JSContext * cx, void * obj, PRInt32 prop, PRBool isWrite)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CheckLoadURIFromScript (in JSContextPtr cx, in nsIURI uri); */
NS_IMETHODIMP nsScriptSecurityManager::CheckLoadURIFromScript(JSContext * cx, nsIURI *uri)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CheckLoadURI (in nsIURI from, in nsIURI uri, in boolean disallowFromMail); */
NS_IMETHODIMP nsScriptSecurityManager::CheckLoadURI(nsIURI *from, nsIURI *uri, PRBool disallowFromMail)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void CheckFunctionAccess (in JSContextPtr cx, in voidPtr funObj, in voidPtr targetObj); */
NS_IMETHODIMP nsScriptSecurityManager::CheckFunctionAccess(JSContext * cx, void * funObj, void * targetObj)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean CanExecuteScripts (in nsIPrincipal principal); */
NS_IMETHODIMP nsScriptSecurityManager::CanExecuteScripts(nsIPrincipal *principal, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RequestCapability (in nsIPrincipal principal, in string capability, out short result); */
NS_IMETHODIMP nsScriptSecurityManager::RequestCapability(nsIPrincipal *principal, const char *capability, PRInt16 *result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean IsCapabilityEnabled (in string capability); */
NS_IMETHODIMP nsScriptSecurityManager::IsCapabilityEnabled(const char *capability, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void EnableCapability (in string capability); */
NS_IMETHODIMP nsScriptSecurityManager::EnableCapability(const char *capability)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void RevertCapability (in string capability); */
NS_IMETHODIMP nsScriptSecurityManager::RevertCapability(const char *capability)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void DisableCapability (in string capability); */
NS_IMETHODIMP nsScriptSecurityManager::DisableCapability(const char *capability)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void SetCanEnableCapability (in string certificateID, in string capability, in short canEnable); */
NS_IMETHODIMP nsScriptSecurityManager::SetCanEnableCapability(const char *certificateID, const char *capability, PRInt16 canEnable)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif

#define NS_SCRIPTSECURITYMANAGER_CONTRACTID "@mozilla.org/scriptsecuritymanager;1"
#define NS_SCRIPTSECURITYMANAGER_CLASSNAME "scriptsecuritymanager"

#endif /* __gen_nsIScriptSecurityManager_h__ */
